@@ -1,6 +1,8 @@
 from functools import wraps
 from .inspector import  Gadget
-from .exceptions import PyCondition
+from .exceptions import PyCondition, PyConditionError
+
+from .stage import Stage
 
 class Pre( object ):
   def __init__( self ):
@@ -34,11 +36,15 @@ class PreCondition( object ):
     pass
 
   def __call__( self, func ):
+    wrapper = func
+    stage = Stage()
+
     self._map( func )
     
     @wraps( func )
     def wrapper( *args, **kwargs ):
-      self.assertCondition( *args, **kwargs )
+      if( stage.name == "Dev" ):
+        self.assertCondition( *args, **kwargs )
       return func( *args, **kwargs )
 
     wrapper._original_func = func
